// generated from rosidl_adapter/resource/msg.idl.em
// with input from controller_manager_msgs/msg/HardwareComponentState.msg
// generated code does not contain a copyright notice

#include "controller_manager_msgs/msg/HardwareInterface.idl"
#include "lifecycle_msgs/msg/State.idl"

module controller_manager_msgs {
  module msg {
    struct HardwareComponentState {
      string name;

      string type;

      string class_type;

      lifecycle_msgs::msg::State state;

      sequence<controller_manager_msgs::msg::HardwareInterface> command_interfaces;

      sequence<controller_manager_msgs::msg::HardwareInterface> state_interfaces;
    };
  };
};
