// generated from rosidl_generator_c/resource/idl.h.em
// with input from controller_manager_msgs:srv/LoadController.idl
// generated code does not contain a copyright notice

#ifndef CONTROLLER_MANAGER_MSGS__SRV__LOAD_CONTROLLER_H_
#define CONTROLLER_MANAGER_MSGS__SRV__LOAD_CONTROLLER_H_

#include "controller_manager_msgs/srv/detail/load_controller__struct.h"
#include "controller_manager_msgs/srv/detail/load_controller__functions.h"
#include "controller_manager_msgs/srv/detail/load_controller__type_support.h"

#endif  // CONTROLLER_MANAGER_MSGS__SRV__LOAD_CONTROLLER_H_
