// generated from rosidl_adapter/resource/msg.idl.em
// with input from controller_manager_msgs/msg/ControllerState.msg
// generated code does not contain a copyright notice


module controller_manager_msgs {
  module msg {
    struct ControllerState {
      string name;

      string state;

      string type;

      sequence<string> claimed_interfaces;

      sequence<string> required_command_interfaces;

      sequence<string> required_state_interfaces;
    };
  };
};
