// generated from rosidl_generator_cpp/resource/idl.hpp.em
// generated code does not contain a copyright notice

#ifndef CONTROLLER_MANAGER_MSGS__SRV__CONFIGURE_START_CONTROLLER_HPP_
#define CONTROLLER_MANAGER_MSGS__SRV__CONFIGURE_START_CONTROLLER_HPP_

#include "controller_manager_msgs/srv/detail/configure_start_controller__struct.hpp"
#include "controller_manager_msgs/srv/detail/configure_start_controller__builder.hpp"
#include "controller_manager_msgs/srv/detail/configure_start_controller__traits.hpp"

#endif  // CONTROLLER_MANAGER_MSGS__SRV__CONFIGURE_START_CONTROLLER_HPP_
