// generated from rosidl_adapter/resource/msg.idl.em
// with input from controller_manager_msgs/msg/HardwareInterface.msg
// generated code does not contain a copyright notice


module controller_manager_msgs {
  module msg {
    struct HardwareInterface {
      string name;

      boolean is_available;

      boolean is_claimed;
    };
  };
};
