// generated from rosidl_adapter/resource/srv.idl.em
// with input from controller_manager_msgs/srv/ConfigureController.srv
// generated code does not contain a copyright notice


module controller_manager_msgs {
  module srv {
    @verbatim (language="comment", text=
      "The ConfigureController service allows you to configure a single controller" "\n"
      "inside controller_manager")
    struct ConfigureController_Request {
      @verbatim (language="comment", text=
        "To configure a controller, specify the \"name\" of the controller." "\n"
        "The return value \"ok\" indicates if the controller was successfully" "\n"
        "configured or not.")
      string name;
    };
    struct ConfigureController_Response {
      boolean ok;
    };
  };
};
